@@ -92,3 +92,7 @@ class backbone_torch:
 
     def tensor2array(self, X_tensor, np_dtype = np.float64):
         return np_dtype(X_tensor.detach().cpu().numpy())
+
+
+    def jit(self, fun):
+        return fun
