@@ -3,7 +3,7 @@ import numpy as np
 
 
 class Problem:
-    def __init__(self, manifold, obj_fun, obj_grad=None, obj_hvp=None, beta = 0, enable_autodiff = True, backbone = None,  **kwargs):
+    def __init__(self, manifold, obj_fun, obj_grad=None, obj_hvp=None, beta = 0, enable_autodiff = True, backbone = None, enable_jit = True,  **kwargs):
         
         self.manifold = manifold
         self.obj_fun = obj_fun 
@@ -50,6 +50,11 @@ class Problem:
             self.cdf_grad = self.manifold.generate_cdf_grad(self.obj_grad, beta)
             self.cdf_hvp = self.manifold.generate_cdf_hess(self.obj_grad, self.obj_hvp, beta)
 
+            if enable_jit:
+                self.cdf_fun = self.backbone.jit(self.cdf_fun)
+                self.cdf_grad = self.backbone.jit(self.cdf_grad)
+                self.cdf_hvp = self.backbone.jit(self.cdf_hvp)
+
 
 
 
@@ -74,12 +79,19 @@ class Problem:
             self.obj_hvp = obj_hvp
 
             self.cdf_fun = self.manifold.generate_cdf_fun(self.obj_fun, beta)
+            if enable_jit:
+                self.cdf_fun = self.backbone.jit(self.cdf_fun)
+            
+            
             self.cdf_fun_vec = lambda y: self.cdf_fun(self.manifold.v2m(y))
 
             
 
             if obj_grad is not None:
                 self.cdf_grad = self.manifold.generate_cdf_grad(self.obj_grad, beta)
+                if enable_jit:
+                    self.cdf_grad = self.backbone.jit(self.cdf_grad)
+
                 self.cdf_grad_vec = lambda y: self.manifold.m2v( self.cdf_grad(self.manifold.v2m(y)) )
 
             else:
@@ -90,6 +102,9 @@ class Problem:
 
             if obj_hvp is not None:
                 self.cdf_hvp = self.manifold.generate_cdf_hess(self.obj_grad, self.obj_hvp, beta)
+                if enable_jit:
+                    self.cdf_hvp = self.backbone.jit(self.cdf_hvp)
+
                 self.cdf_hvp_vec = lambda y,p: self.manifold.m2v( self.cdf_hvp(self.manifold.v2m(y), self.manifold.v2m(p)) )
 
             else:
