@@ -50,8 +50,8 @@ class basic_manifold(metaclass=abc.ABCMeta):
         self.sum = self.backbone.func_sum 
         self.sqrt = self.backbone.func_sqrt 
 
-        self.array2tensor = self.backbone.array2tensor
-        self.tensor2array = self.backbone.tensor2array
+        # self.array2tensor = self.backbone.array2tensor
+        # self.tensor2array = self.backbone.tensor2array
             # autograd.vjp has low compatibality to the autograd.linalg.solve or autograd.linalg.pinv
             # hence we choose the linear_map_adjoint to generate jvp from vjp.
             # On the other hand, mathematically, jvp and vjp are equivalent. Therefore, it would be better 
@@ -105,18 +105,18 @@ class basic_manifold(metaclass=abc.ABCMeta):
         """
 
     # @_raise_not_implemented_error
-    # def array2tensor(self, X_array):
-    #     """
-    #     Transfer the numpy array to variables
-    #     """
-
+    def array2tensor(self, X_array):
+        """
+        Transfer the numpy array to variables
+        """
+        return self.backbone.array2tensor(X_array)
 
     # @_raise_not_implemented_error
-    # def tensor2array(self, X_tensor):
-    #     """
-    #     Transfer the variables to array
-    #     """
-
+    def tensor2array(self, X_tensor):
+        """
+        Transfer the variables to array
+        """
+        return self.backbone.tensor2array(X_tensor)
 
 
     @ _raise_not_implemented_error
